==> nextcloud-app-mail-0.11.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/zh_CN.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "邮件",
    "Loading accounts" : "加载账户中",
    "Error while loading the accounts." : "载入账户时出错。",
    "Can not load this folder." : "不能读取这个文件夹",
    "Searching for {query}" : "正在搜索 {query}",
    "Error while deleting message." : "删除消息时出错。",
    "Forwarded message" : "转发的消息",
    "Choose a folder to store the attachment in" : "选择附件保存的文件夹",
    "Attachments saved to Files." : "附件已保存到文件。",
    "Attachment saved to Files." : "附件已保存到文件。",
    "Error while saving attachments to Files." : "保存附件到文件时发生错误。",
    "Error while saving attachment to Files." : "保存附件到文件时发生错误。",
    "Message flag could not be set." : "无法设置消息标记。",
    "Could not move message." : "无法移动消息。",
    "Invalid account" : "无效的账户。",
    "Invalid folder" : "无效的文件夹",
    "Error while creating the account: " : "创建账户时出错：",
    "Unknown error" : "未知错误",
    "Error while updating the account: " : "更新账户时出错：",
    "All inboxes" : "所有收件箱",
    "you" : "您",
    "Send message to {email}" : "发送消息至 {email}",
    "Could not load {tag}{name}{endtag}" : "无法加载 {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "加载 {tag}{name}{endtag} 时出现问题",
    "Could not load your message" : "无法加载您的消息",
    "Could not load the desired message" : "无法加载想要的消息",
    "Could not load the message" : "无法加载该消息",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["来自 {from} 的 %n 条新消息"],
    "Nextcloud Mail" : "Nextcloud 邮件",
    "Save" : "保存",
    "Saved" : "已保存",
    "Show all folders" : "显示全部文件夹",
    "Collapse folders" : "折叠文件夹",
    "Error while deleting account." : "删除账户时出错",
    "Choose a file to add as attachment" : "选择文件添加为附件",
    "An error occurred while uploading {fname}" : "上传是发生错误 {fname}",
    "Reply" : "回复",
    "Send" : "发送",
    "Sending …" : "正在发送…",
    "Message sent!" : "消息已发送！",
    "Server error" : "服务器错误",
    "An unknown error occurred" : "遇到未知错误",
    "Opening HTML drafts is not supported yet." : "暂时未能打开HTML格式的草稿，请见谅。",
    "No writable calendars found" : "未找到可写的日历",
    "Error while importing the calendar event" : "导入日历事件错误",
    "Error while downloading calendar event" : "下载日历事件错误",
    "& others" : "和其他",
    "Error while loading messages." : "载入消息时发生错误。",
    "Error while refreshing messages." : "刷新消息时发生错误。",
    "Setting up your account" : "设置你的账户",
    "Inbox" : "收件箱",
    "Sent" : "已发送",
    "Drafts" : "草稿",
    "Archive" : "归档",
    "Trash" : "废件箱",
    "Junk" : "垃圾邮件",
    "All" : "全部",
    "Favorites" : "收藏",
    "Auto detect failed. Please use manual mode." : "自动检测失败，请使用手动模式。",
    "Updating account failed: " : "更新账户失败：",
    "Creating account failed: " : "未能创建账户：",
    "Delete permanently" : "永久删除",
    "Error loading message" : "载入电邮时发生错误",
    "Settings" : "设置",
    "Forwarding to %s" : "转发给 %s",
    "Click here if you are not automatically redirected within the next few seconds." : "如果您在接下来几秒钟内未被自动重定向，请点击此处。",
    "Redirect" : "重定向",
    "The link leads to %s" : "链接指向 %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "如果您不想访问此网页，您可以返回到<a href=\"%s\">邮件</a>应用。",
    "Continue to %s" : "继续 %s",
    "Delete account" : "删除账户",
    "Try again" : "重试",
    "New message" : "新建消息",
    "Account Settings" : "账户设置",
    "Aliases" : "别名",
    "Mail address" : "邮箱",
    "Display Name" : "显示名称",
    "Account" : "账户",
    "Delete" : "删除",
    "Keyboard shortcuts" : "键盘快捷方式",
    "Speed up your Mail experience with these quick shortcuts." : "利用这些快捷方式使您的邮件使用过程更加迅捷",
    "Compose new message" : "撰写新消息",
    "Newer message" : "更新的信息",
    "Older message" : "更早的信息",
    "Toggle star" : "切换星标",
    "Toggle unread" : "切换未读",
    "Search" : "搜索",
    "Refresh" : "刷新",
    "Connect your mail account" : "连接您的邮件账户",
    "Name" : "姓名",
    "Mail Address" : "邮箱",
    "Password" : "密码",
    "Manual configuration" : "手动配置",
    "IMAP Host" : "IMAP 主机",
    "IMAP security" : "IMAP 安全",
    "None" : "无",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP 端口",
    "IMAP User" : "IMAP 用户",
    "IMAP Password" : "IMAP 密码",
    "SMTP Host" : "SMTP 主机",
    "SMTP security" : "SMTP 安全",
    "SMTP Port" : "SMTP 端口",
    "SMTP User" : "SMTP 用户",
    "SMTP Password" : "SMTP 密码",
    "Connect" : "连接",
    "from" : "发件人",
    "to" : "收件人",
    "cc" : "抄送",
    "bcc" : "密送",
    "Subject" : "主题",
    "Save all to Files" : "全部保存到文件",
    "Add mail account" : "添加邮件账户",
    "No search results for" : "未找到搜索结果",
    "The images have been blocked to protect your privacy." : "图片已被禁用，以保护您的隐私。",
    "Show images from this sender" : "显示此发件人的图片",
    "Forward" : "转发",
    "No messages in this folder" : "该文件夹内没有消息",
    "Upload attachment" : "上传附件",
    "Add attachment from Files" : "从文件添加附件",
    "Import into calendar" : "导入到日历",
    "Download attachment" : "下载附件",
    "Save to Files" : "保存到“文件”"
},
"nplurals=1; plural=0;");

==> nextcloud-app-mail-0.14.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/zh_CN.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "邮件",
    "Inbox" : "收件箱",
    "Sent" : "已发送",
    "Drafts" : "草稿",
    "Archive" : "归档",
    "Trash" : "废件箱",
    "Junk" : "垃圾邮件",
    "All" : "全部",
    "Favorites" : "收藏",
    "Auto detect failed. Please use manual mode." : "自动检测失败，请使用手动模式。",
    "Updating account failed: " : "更新账户失败：",
    "Creating account failed: " : "未能创建账户：",
    "Delete permanently" : "永久删除",
    "IMAP web client" : "IMAP 网页客户端",
    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "使用邮件客户端更容易通过 IMAP 和 SMTP 连接到您的邮件服务器。",
    "Auto" : "自动",
    "Name" : "姓名",
    "Mail Address" : "邮箱",
    "Password" : "密码",
    "Manual" : "手册",
    "IMAP Settings" : "IMAP设置",
    "IMAP Host" : "IMAP 主机",
    "IMAP Security" : "IMAP安全",
    "None" : "无",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP 端口",
    "IMAP User" : "IMAP 用户",
    "IMAP Password" : "IMAP 密码",
    "SMTP Settings" : "SMTP设置",
    "SMTP Host" : "SMTP 主机",
    "SMTP Security" : "SMTP安全",
    "SMTP Port" : "SMTP 端口",
    "SMTP User" : "SMTP 用户",
    "SMTP Password" : "SMTP 密码",
    "Save" : "保存",
    "Connect" : "连接",
    "Add mail account" : "添加邮件账户",
    "Use Gravatar and favicon avatars" : "使用 Gravatar 和 favicon 形象",
    "Keyboard shortcuts" : "键盘快捷方式",
    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "在寻找加密您邮件的方法吗？安装Mailvelope浏览器扩展！",
    "from" : "发件人",
    "to" : "收件人",
    "+ cc/bcc" : "+ cc/bcc",
    "cc" : "抄送",
    "bcc" : "密送",
    "Subject" : "主题",
    "Note that the mail came from a noreply address so\tyour reply will probably not be read." : "此邮件来自一个无法回复的地址，您的回复将可能无法被阅读。",
    "Message …" : "消息 …",
    "Saving draft …" : "保存草稿 …",
    "Draft saved" : "草稿已保存",
    "Uploading attachments …" : "上传附件 …",
    "Sending …" : "正在发送…",
    "Error sending your message" : "发送您的消息时出错",
    "Go back" : "后退",
    "Retry" : "重试",
    "Message sent!" : "消息已发送！",
    "Reply sent!" : "回复已发送！",
    "Write another message" : "写另一条消息",
    "Send" : "发送",
    "Uploading {percent}% …" : "正在上传 {percent}% …",
    "Upload attachment" : "上传附件",
    "Add attachment from Files" : "从文件添加附件",
    "Choose a file to add as attachment" : "选择文件添加为附件",
    "No messages in this folder" : "该文件夹内没有消息",
    "Draft: " : "草稿: ",
    "Mark read" : "标记为已读",
    "Mark unread" : "标记为未读",
    "Delete" : "删除",
    "Report this bug" : "报告此问题",
    "Loading messages" : "加载消息",
    "Not found" : "没有找到",
    "Could not load your message" : "无法加载您的消息",
    "Import into calendar" : "导入到日历",
    "Download attachment" : "下载附件",
    "Save to Files" : "保存到“文件”",
    "Choose a folder to store the attachment in" : "选择附件保存的文件夹",
    "Save all to Files" : "全部保存到文件",
    "Choose a folder to store the attachments in" : "选择附件保存的目录",
    "The images have been blocked to protect your privacy." : "图片已被禁用，以保护您的隐私。",
    "Show images from this\tsender" : "显示此发件人的图片",
    "New message" : "新建消息",
    "Settings" : "设置",
    "Edit" : "编辑",
    "Show all folders" : "显示全部文件夹",
    "Collapse folders" : "折叠文件夹",
    "Could not load your draft" : "无法加载您的草稿",
    "No message selected" : "没有选择消息",
    "Signature" : "签名",
    "A signature will be added to the text of new and response messages." : "签名将加入到新邮件及回复邮件的文本中。",
    "Account Settings" : "账户设置",
    "Mail server" : "邮件服务器",
    "Speed up your Mail experience with these quick shortcuts." : "利用这些快捷方式使您的邮件使用过程更加迅捷",
    "Compose new message" : "撰写新消息",
    "Newer message" : "更新的信息",
    "Older message" : "更早的信息",
    "Toggle star" : "切换星标",
    "Toggle unread" : "切换未读",
    "Search" : "搜索",
    "Refresh" : "刷新",
    "Connect your mail account" : "连接您的邮件账户",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["来自 {from} 的 %n 条新消息"],
    "Nextcloud Mail" : "Nextcloud 邮件",
    "All inboxes" : "所有收件箱",
    "Could not load {tag}{name}{endtag}" : "无法加载 {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "加载 {tag}{name}{endtag} 时出现问题",
    "Could not load the desired message" : "无法加载想要的消息",
    "Could not load the message" : "无法加载该消息",
    "Error loading message" : "载入电邮时发生错误",
    "Forwarding to %s" : "转发给 %s",
    "Click here if you are not automatically redirected within the next few seconds." : "如果您在接下来几秒钟内未被自动重定向，请点击此处。",
    "Redirect" : "重定向",
    "The link leads to %s" : "链接指向 %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "如果您不想访问此网页，您可以返回到<a href=\"%s\">邮件</a>应用。",
    "Continue to %s" : "继续 %s"
},
"nplurals=1; plural=0;");
